jQuery.extend( jQuery.fn.pickadate.defaults, {
    monthsFull: [ 'जनवरी', 'फरवरी', 'मार्च', 'अप्रैल', 'मई', 'जून', 'जुलाई', 'अगस्त', 'सितम्बर', 'अक्टूबर', 'नवम्बर', 'दिसम्बर' ],
    monthsShort: [ 'जन', 'फर', 'मार्च', 'अप्रैल', 'मई', 'जून', 'जु', 'अग', 'सित', 'अक्टू', 'नव', 'दिस' ],
    weekdaysFull: [ 'रविवार', 'सोमवार', 'मंगलवार', 'बुधवार', 'गुरुवार', 'शुक्रवार', 'शनिवार' ],
    weekdaysShort: [ 'रवि', 'सोम', 'मंगल', 'बुध', 'गुरु', 'शुक्र','शनि' ],
    today: 'आज की तारीख चयन करें',
    clear: 'चुनी हुई तारीख को मिटाएँ',
    close: 'विंडो बंद करे',
    firstDay: 1,
    format: 'dd/mm/yyyy',
    formatSubmit: 'yyyy/mm/dd',
    labelMonthNext: 'अगले माह का चयन करें',
    labelMonthPrev: 'पिछले माह का चयन करें',
    labelMonthSelect: 'किसि एक महीने का चयन करें',
    labelYearSelect: 'किसि एक वर्ष का चयन करें'
});

jQuery.extend( jQuery.fn.pickatime.defaults, {
    clear: 'चुनी हुई तारीख को मिटाएँ'
});
