{% if form.non_field_errors %}
<div class="ui error message">
    {% if form_error_title %}<div class="header">{{ form_error_title }}</div>{% endif %}
    <ul class="list">
        {{ form.non_field_errors|unordered_list }}
    </ul>
</div>
{% endif %}
